# database objects for running adapter specs
# ADO_DB = Sequel.connect(:adapter => 'ado', :driver => "{Microsoft Access Driver (*.mdb)}; DBQ=c:\\Nwind.mdb")
# INFORMIX_DB = Sequel.connect('informix://localhost/mydb')
# INTEGRATION_URL = 'sqlite:/'
# MYSQL_USER = 'root'
# MYSQL_URL = "mysql://#{MYSQL_USER}@localhost/sandbox"
# MYSQL_SOCKET_FILE = '/tmp/mysql.sock'
# ORACLE_DB = Sequel.connect('oracle://hr:hr@localhost/XE')
POSTGRES_URL = 'postgres:///sequel_test?user=postgres'
# SQLITE_URL = 'sqlite:/'
